pub enum ConversionError {
Negative,
Nan,
Infinite,
Overflow,
Underflow,
}Expand description
Error returned by fallible conversions into unsigned float types.
Variants
Negative
The source value was less than zero.
Nan
The source value was NaN.
Infinite
The source value was infinite.
Overflow
The source value was too large for the target format.
Underflow
The positive source value was too small for the target format.