SimdError

Enum SimdError 

pub enum SimdError {
    InputLengthMismatch {
        left: usize,
        right: usize,
    },
    OutputLengthMismatch {
        input: usize,
        output: usize,
    },
}
Invalid source/destination slice relationship passed to a bulk operation.

Variants



InputLengthMismatch

Two input planes that must be elementwise aligned have different sizes.

Fields

left: usize
right: usize


OutputLengthMismatch

The output plane does not have one element for each input element.

Fields

input: usize
output: usize