pub trait Pow1mUf<Rhs> {
type Output;
// Required method
fn pow1muf(self, rhs: Rhs) -> Self::Output;
}Expand description
Extension trait for evaluating (1 - self)^rhs.
This is useful for probability and interpolation kernels where self is
already the complement input u, not the power base.
Required Associated Types
Required Methods
Implementations on Foreign Types
Sourceimpl Pow1mUf<Uf64E11M52> for f32
Available on crate feature f128 only.
impl Pow1mUf<Uf64E11M52> for f32
Available on crate feature
f128 only.Sourceimpl Pow1mUf<Uf64E11M52> for f64
Available on crate feature f128 only.
impl Pow1mUf<Uf64E11M52> for f64
Available on crate feature
f128 only.