pub enum SimdError {
InputLengthMismatch {
left: usize,
right: usize,
},
OutputLengthMismatch {
input: usize,
output: usize,
},
}Expand description
Invalid source/destination slice relationship passed to a bulk operation.
Variants
InputLengthMismatch
Two input planes that must be elementwise aligned have different sizes.
OutputLengthMismatch
The output plane does not have one element for each input element.