Pow1mUf

Trait Pow1mUf 

pub trait Pow1mUf<Rhs> {
    type Output;

    // Required method
    fn pow1muf(self, rhs: Rhs) -> Self::Output;
}
Extension trait for evaluating (1 - self)^rhs.

This is useful for probability and interpolation kernels where self is already the complement input u, not the power base.

Required Associated Types

type Output

The result type of complement exponentiation.

Required Methods

fn pow1muf(self, rhs: Rhs) -> Self::Output

Raises 1 - self to the unsigned-float exponent rhs.

Implementations on Foreign Types

Source

impl Pow1mUf<Uf8E4M4> for f32

Source

type Output = f32

Source

fn pow1muf(self, rhs: Uf8) -> Self::Output

Source

impl Pow1mUf<Uf8E4M4> for f64

Source

type Output = f64

Source

fn pow1muf(self, rhs: Uf8) -> Self::Output

Source

impl Pow1mUf<Uf8E5M3> for f32

Source

type Output = f32

Source

fn pow1muf(self, rhs: Uf8E5M3) -> Self::Output

Source

impl Pow1mUf<Uf8E5M3> for f64

Source

type Output = f64

Source

fn pow1muf(self, rhs: Uf8E5M3) -> Self::Output

Source

impl Pow1mUf<Uf16E5M11> for f32

Source

type Output = f32

Source

fn pow1muf(self, rhs: Uf16) -> Self::Output

Source

impl Pow1mUf<Uf16E5M11> for f64

Source

type Output = f64

Source

fn pow1muf(self, rhs: Uf16) -> Self::Output

Source

impl Pow1mUf<Uf16E6M10> for f32

Source

type Output = f32

Source

fn pow1muf(self, rhs: Uf16E6M10) -> Self::Output

Source

impl Pow1mUf<Uf16E6M10> for f64

Source

type Output = f64

Source

fn pow1muf(self, rhs: Uf16E6M10) -> Self::Output

Source

impl Pow1mUf<Uf32E8M24> for f32

Source

type Output = f32

Source

fn pow1muf(self, rhs: Uf32) -> Self::Output

Source

impl Pow1mUf<Uf32E8M24> for f64

Source

type Output = f64

Source

fn pow1muf(self, rhs: Uf32) -> Self::Output

Source

impl Pow1mUf<Uf64E11M52> for f32

Available on crate feature f128 only.
Source

type Output = f32

Source

fn pow1muf(self, rhs: Uf64) -> Self::Output

Source

impl Pow1mUf<Uf64E11M52> for f64

Available on crate feature f128 only.
Source

type Output = f64

Source

fn pow1muf(self, rhs: Uf64) -> Self::Output

Implementors